// async/await gives us back control flow statements, including exception
// handling!

const { join: joinPaths } = require('path')
const { readdir, stat } = require('fs').promises

run(process.argv[2] || process.cwd())

async function run(path) {
  // Exceptions throw in the proper scope...
  try {
    const results = []

    // Loops work...
    for (const name of await readdir(path)) {
      // Notice that we don’t parallelize `stat` calls to the filesystem here:
      // to do that, we would need to create all promises earlier then do a
      // `Promise.all` on the result, for instance.
      const { size } = await stat(joinPaths(path, name))
      results.push({ name, size })
    }

    console.table(results)
  } catch (err) {
    console.warn(err.message)
  }
}
