// An `async` function protects 100% of its code in a promise chain

const { stat } = require('fs').promises

async function faultySize(path) {
  // OUCH! `strip()` does not exist: its JS equivalent is `trim()`...
  path = path.strip()
  const { size } = await stat(path)
  return size
}

console.time('size')
faultySize('regular')
  // We’ll never get in there...
  .then((size) => console.timeEnd('size', size))
  // ...but we will get in this one, as the initial error was indeed captured by
  // the promise chain that wraps any `async` function :-)
  .catch((err) => console.warn('size', err.message))
