// You can parallelize by doing an `await` on a `Promise.all`.
//
// Note: we’ll refactor towards a better version in a moment.

const { join: joinPaths } = require('path')
const { readdir, stat } = require('fs').promises

run(process.argv[2] || process.cwd())

async function run(path) {
  const names = await readdir(path)
  // We launch all `stat`-based promises ahead, before the `await`, so they are
  // in fact run in parallel.
  const stats = names.map((name) => stat(joinPaths(path, name)))
  const results = []

  // An `await` on the `Promise.all` will suspend and eventually resume with the
  // array of fulfilled values; by calling `.entries()` we get indices too, in
  // order to grab the matching name in `names`.  This is hackish but don’t
  // worry, we’ll improve this in a moment.
  for (const [index, { size }] of (await Promise.all(stats)).entries()) {
    results.push({ name: names[index], size })
  }

  console.table(results)
}
