// You can parallelize by doing an `await` on a `Promise.all`.

const { join: joinPaths } = require('path')
const { readdir, stat } = require('fs').promises

run(process.argv[2] || process.cwd())

async function run(path) {
  const names = await readdir(path)
  // Notice that the callback is itself `async`: it therefore does return a
  // promise.  But this one pre-builds the relevant `{ name, size }` object,
  // which spares us from having to re-tweak the results array later with
  // index-based hacks...
  const stats = names.map(async (name) => {
    const { size } = await stat(joinPaths(path, name))
    return { name, size }
  })

  console.table(await Promise.all(stats))
}
