// As this code looks synchronous, it’s easy to fall back into our bad habits
// and forget to parallelize...

async function needlesslyLongListPosts(req, res) {
  // These three requests are fully independent from each other: it would be a
  // pity to sequence them instead of parallelizing them, as the latter would
  // result in a much shorter overall response time!
  const results = await Post.search(req.query.filter)
  const totalCount = await Post.estimatedCount()
  const tags = await Post.tags({ top: 10 })

  res.render('posts/index', { results, totalCount, tags })
}

async function listPosts(req, res) {
  // Here, we create all promises early, then combine them to get all three
  // results eventually, without having to worry about their completion order.
  // Total time: whichever takes longest to run.
  const [results, totalCount, tags] = await Promise.all([
    Post.search(req.query.filter),
    Post.estimatedCount(),
    Post.tags({ top: 10 }),
  ])

  res.render('posts/index', { results, totalCount, tags })
}
