// When you want to sequence processings, you don’t necessarily need to sequence
// the actual underlying async work, perhaps just the handling of their results.

async function needlesslyLongSequence(chapterURLs) {
  for (const chapterURL of chapterURLs) {
    // This waits for each chapter to complete before event requesting the next
    // one, when in fact all these requests are independent from each other...
    const chapter = await fetchChapterText(chapterURL)
    appendChapterToPage(chapter)
  }
}

async function goodSequence(chapterURLs) {
  const chapterFetches = chapterURLs.map(fetchChapterText)
  // All requests are initiated early, so they run in parallel.  However, our
  // loop preserves the definition order of chapters, in order to add them in
  // the proper order, as soon as each one becomes available (and not once
  // they’re all fetched, which is what an `await Promise.all(chapterFetches)`
  // would do).  Parallel requests, but sequential result handling!
  for (const chapterFetch of chapterFetches) {
    const chapter = await chapterFetch
    appendChapterToPage(chapter)
  }
}
