// `return await` really only makes sense inside a try-catch

async function dumbFetcher(email, password) {
  password = await bcrypt.hash(password, 10)
  // This is useless, as we are returning a promise on the result anyway and
  // don’t want to alter its settlement, so we might as well return the
  // underlying promise...
  return await userInfo.findOne().where({ email, password })
}

async function fetcher(email, password) {
  password = await bcrypt.hash(password, 10)
  return userInfo.findOne().where({ email, password })
}

async function shieldedFetcher(email, password) {
  password = await bcrypt.hash(password, 10)
  try {
    return await userInfo.findOne().where({ email, password })
  } catch (err) {
    // Because we want to capture a potential rejection to turn it into a `null`
    // fulfillment, unless we latch a manual `.catch()` on the returned promise,
    // we need a `return await` for the rejection to become a local `throw`.
    console.warn('User fetching error:', err)
    return null
  }
}
